# MIB Generator
[![Documentation Status](https://readthedocs.org/projects/mib-generator/badge/?version=latest)](https://mib-generator.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/mib-generator)](https://pypi.org/project/mib-generator)
[![Black](https://img.shields.io/badge/code_style-black-black)](https://github.com/psf/black)
[![MIT](https://img.shields.io/badge/license-MIT-purple)](https://github.com/vachaj11/MIB-Generator/blob/main/LICENSE)

A set of python scripts that create a SCOS 2000[^1] MIB database from inputted C-header files. It includes basic abilities for 1. parsing of C syntax, 2. interpreting it along the lines of expected structure of monitoring and telecommunication packet declarations and 3. creating corresponding MIB databases.

The code is hosted on [Github](https://github.com/vachaj11/MIB-Generator) and releases are published on [PyPI](https://pypi.org/project/mib-generator).

For instruction on installation/building and usage or more general information about the project see the documentation hosted on [Read The Docs](https://mib-generator.readthedocs.io/en/latest/index.html) ([in pdf](https://mib-generator.readthedocs.io/_/downloads/en/latest/pdf/)).

[^1]: Satellite Mission Control System developed by the European Space Agency.
